# ordered

The ones I know of (and which made me write mdv ;-) ):

1. There
    1. foo
        1. foo
            1. foo
                1. foo
                    1. foo
                        1. foo
1. pandoc
1. vimcat

Summary: ...

